==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Kontrolli thuajse është plotësuar, faleminderit që bëni durim</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Po përgatitet</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>U kontrollua për disa gabime</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Kalo në Desktop</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Mirë se erdhët, sistemi u përditësua me sukses</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Edicioni i Tanishëm:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Shihni Regjistra</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Përditësime me sukses</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Kompjuteri juaj do të riniset së shpejti %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Kompjuteri juaj do të fiket së shpejti %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Procesi i rinisjes së automatizuar dështoi. Ju lutemi, provoni ta rinisni dorazi pajisjen tuaj.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Procesi i fikjes së automatizuar dështoi. Ju lutemi, provoni ta fikni dorazi pajisjen tuaj.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Fshihi Regjistrat</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Përditësimi dështoi</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Gabim i panjohur</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Kopjeruajtja dështoi</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>S’arrihet të kryhet kopjeruajtje sistemi. Nëse vazhdoni përditësimet, s’mund të ktheheni prapa te sistemi i vjetër më vonë.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Hapësirë e pamjaftueshme disku. Ju lutemi, pastroni diskun dhe riprovoni.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>S’u arrit të lidhej te shërbime kopjeruajtjeje. Ju lutemi, kontrollojeni dhe riprovoni.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>S’u arrit të lidhej me shërbime përditësimi. Ju lutemi, kontrollojeni dhe riprovoni.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Gabim varësish</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Gabim DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Ribëj Kopjeruajtje</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Ndërprite</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Vazhdo me Përditësimin</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Fiku</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Kalo në Desktop</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Po përgatitet për përditësime…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Mos bëni fikje ose heqje energjie të makinës, kur instalohen përditësime. Përndryshe, sistemi juaj mund të dëmtohet.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-update/translations/dde-update_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Kontrolli thuajse është plotësuar, faleminderit që bëni durim</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Po përgatitet</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>U kontrollua për disa gabime</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Kalo në Desktop</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Mirë se erdhët, sistemi u përditësua me sukses</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Edicioni i Tanishëm:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Përditësime me sukses</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Kompjuteri juaj do të riniset së shpejti %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Kompjuteri juaj do të fiket së shpejti %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Procesi i rinisjes së automatizuar dështoi. Ju lutemi, provoni ta rinisni dorazi pajisjen tuaj.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Procesi i fikjes së automatizuar dështoi. Ju lutemi, provoni ta fikni dorazi pajisjen tuaj.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Shihni regjistra përditësimesh</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Palosi regjistrat e përditësimeve</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Eksportoje</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Regjistri u eksportua te desktopi</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Eksportimi i regjistrit dështoi, ju lutemi, riprovoni</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Përditësimi dështoi</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Gabim i panjohur</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Kopjeruajtja dështoi</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>S’arrihet të kryhet kopjeruajtje sistemi. Nëse vazhdoni përditësimet, s’mund të ktheheni prapa te sistemi i vjetër më vonë.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Hapësirë e pamjaftueshme disku. Ju lutemi, pastroni diskun dhe riprovoni.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>S’u arrit të lidhej te shërbime kopjeruajtjeje. Ju lutemi, kontrollojeni dhe riprovoni.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>S’u arrit të lidhej me shërbime përditësimi. Ju lutemi, kontrollojeni dhe riprovoni.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Gabim varësish</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Gabim DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Ribëj Kopjeruajtje</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Ndërprite</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Vazhdo me Përditësimin</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Fiku</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Kalo në Desktop</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Po përgatitet për përditësime…</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Mos bëni fikje ose heqje energjie të makinës, kur instalohen përditësime. Përndryshe, sistemi juaj mund të dëmtohet.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Shihni regjistra përditësimesh</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Palosi regjistrat e përditësimeve</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
